# Lucide Icons
from .icons.hand_helping import HandHelping
from .icons.underline import Underline
from .icons.file_type_corner import FileTypeCorner
from .icons.sigma import Sigma
from .icons.clock_9 import Clock9
from .icons.triangle_alert import TriangleAlert
from .icons.ethernet_port import EthernetPort
from .icons.triangle import Triangle
from .icons.hand import Hand
from .icons.search import Search
from .icons.chart_scatter import ChartScatter
from .icons.signpost_big import SignpostBig
from .icons.volume_2 import Volume2
from .icons.hand_heart import HandHeart
from .icons.columns_3_cog import Columns3Cog
from .icons.contact import Contact
from .icons.beer_off import BeerOff
from .icons.send_horizontal import SendHorizontal
from .icons.move_down import MoveDown
from .icons.clipboard_plus import ClipboardPlus
from .icons.gamepad_2 import Gamepad2
from .icons.lectern import Lectern
from .icons.lasso import Lasso
from .icons.eraser import Eraser
from .icons.chart_line import ChartLine
from .icons.disc_2 import Disc2
from .icons.receipt import Receipt
from .icons.bed_single import BedSingle
from .icons.wine import Wine
from .icons.briefcase_medical import BriefcaseMedical
from .icons.ice_cream_bowl import IceCreamBowl
from .icons.parking_meter import ParkingMeter
from .icons.file_search import FileSearch
from .icons.arrow_down import ArrowDown
from .icons.check_line import CheckLine
from .icons.figma import Figma
from .icons.corner_right_up import CornerRightUp
from .icons.file_key import FileKey
from .icons.earth import Earth
from .icons.laptop_minimal_check import LaptopMinimalCheck
from .icons.chevrons_right import ChevronsRight
from .icons.beef import Beef
from .icons.flashlight import Flashlight
from .icons.file_pen import FilePen
from .icons.ghost import Ghost
from .icons.monitor_cloud import MonitorCloud
from .icons.list import List
from .icons.biceps_flexed import BicepsFlexed
from .icons.cctv import Cctv
from .icons.volume_off import VolumeOff
from .icons.text_cursor_input import TextCursorInput
from .icons.image_upscale import ImageUpscale
from .icons.megaphone import Megaphone
from .icons.croissant import Croissant
from .icons.toy_brick import ToyBrick
from .icons.pencil_off import PencilOff
from .icons.route_off import RouteOff
from .icons.square_arrow_right import SquareArrowRight
from .icons.briefcase_business import BriefcaseBusiness
from .icons.house import House
from .icons.swiss_franc import SwissFranc
from .icons.navigation_2_off import Navigation2Off
from .icons.bluetooth_off import BluetoothOff
from .icons.bed import Bed
from .icons.panel_right_close import PanelRightClose
from .icons.signal_low import SignalLow
from .icons.chevrons_down import ChevronsDown
from .icons.memory_stick import MemoryStick
from .icons.clock_arrow_down import ClockArrowDown
from .icons.disc_3 import Disc3
from .icons.wind import Wind
from .icons.corner_up_right import CornerUpRight
from .icons.clapperboard import Clapperboard
from .icons.subscript import Subscript
from .icons.file_digit import FileDigit
from .icons.arrow_big_down_dash import ArrowBigDownDash
from .icons.grape import Grape
from .icons.flip_vertical import FlipVertical
from .icons.hdmi_port import HdmiPort
from .icons.target import Target
from .icons.user_cog import UserCog
from .icons.scissors import Scissors
from .icons.minimize_2 import Minimize2
from .icons.cog import Cog
from .icons.waypoints import Waypoints
from .icons.megaphone_off import MegaphoneOff
from .icons.file_video_camera import FileVideoCamera
from .icons.receipt_pound_sterling import ReceiptPoundSterling
from .icons.crosshair import Crosshair
from .icons.align_vertical_distribute_end import AlignVerticalDistributeEnd
from .icons.pi import Pi
from .icons.table_cells_merge import TableCellsMerge
from .icons.square_equal import SquareEqual
from .icons.file_sliders import FileSliders
from .icons.package_open import PackageOpen
from .icons.vegan import Vegan
from .icons.airplay import Airplay
from .icons.gallery_thumbnails import GalleryThumbnails
from .icons.clock_8 import Clock8
from .icons.section import Section
from .icons.message_circle_warning import MessageCircleWarning
from .icons.line_squiggle import LineSquiggle
from .icons.badge_euro import BadgeEuro
from .icons.repeat import Repeat
from .icons.circle_user_round import CircleUserRound
from .icons.square_chevron_right import SquareChevronRight
from .icons.arrow_right_left import ArrowRightLeft
from .icons.grip import Grip
from .icons.luggage import Luggage
from .icons.badge_turkish_lira import BadgeTurkishLira
from .icons.hourglass import Hourglass
from .icons.russian_ruble import RussianRuble
from .icons.circle_chevron_right import CircleChevronRight
from .icons.microwave import Microwave
from .icons.volume_1 import Volume1
from .icons.party_popper import PartyPopper
from .icons.boxes import Boxes
from .icons.file_heart import FileHeart
from .icons.chess_rook import ChessRook
from .icons.printer_check import PrinterCheck
from .icons.reply import Reply
from .icons.badge_percent import BadgePercent
from .icons.type_outline import TypeOutline
from .icons.square_dashed_kanban import SquareDashedKanban
from .icons.hamburger import Hamburger
from .icons.sunrise import Sunrise
from .icons.toggle_right import ToggleRight
from .icons.square_star import SquareStar
from .icons.map_pin_plus_inside import MapPinPlusInside
from .icons.bug_off import BugOff
from .icons.message_square_share import MessageSquareShare
from .icons.beer import Beer
from .icons.pointer import Pointer
from .icons.receipt_indian_rupee import ReceiptIndianRupee
from .icons.chess_knight import ChessKnight
from .icons.chart_bar_stacked import ChartBarStacked
from .icons.squares_intersect import SquaresIntersect
from .icons.sheet import Sheet
from .icons.spray_can import SprayCan
from .icons.scan_line import ScanLine
from .icons.circle_check_big import CircleCheckBig
from .icons.unfold_vertical import UnfoldVertical
from .icons.chart_candlestick import ChartCandlestick
from .icons.git_pull_request_draft import GitPullRequestDraft
from .icons.chart_no_axes_column_increasing import ChartNoAxesColumnIncreasing
from .icons.layout_list import LayoutList
from .icons.umbrella import Umbrella
from .icons.user import User
from .icons.list_start import ListStart
from .icons.file_chart_column_increasing import FileChartColumnIncreasing
from .icons.lasso_select import LassoSelect
from .icons.arrow_big_down import ArrowBigDown
from .icons.iteration_cw import IterationCw
from .icons.fullscreen import Fullscreen
from .icons.message_circle_heart import MessageCircleHeart
from .icons.sun_dim import SunDim
from .icons.saudi_riyal import SaudiRiyal
from .icons.chart_network import ChartNetwork
from .icons.replace_all import ReplaceAll
from .icons.square_arrow_out_down_left import SquareArrowOutDownLeft
from .icons.cannabis import Cannabis
from .icons.iteration_ccw import IterationCcw
from .icons.message_circle_more import MessageCircleMore
from .icons.file_minus import FileMinus
from .icons.heart_plus import HeartPlus
from .icons.square_power import SquarePower
from .icons.square_chevron_up import SquareChevronUp
from .icons.panda import Panda
from .icons.align_horizontal_justify_start import AlignHorizontalJustifyStart
from .icons.copy_plus import CopyPlus
from .icons.timer_off import TimerOff
from .icons.folder_check import FolderCheck
from .icons.chart_column_decreasing import ChartColumnDecreasing
from .icons.badge_japanese_yen import BadgeJapaneseYen
from .icons.arrow_up_from_line import ArrowUpFromLine
from .icons.flip_vertical_2 import FlipVertical2
from .icons.annoyed import Annoyed
from .icons.ligature import Ligature
from .icons.message_square_warning import MessageSquareWarning
from .icons.layout_grid import LayoutGrid
from .icons.rocking_chair import RockingChair
from .icons.chevrons_up_down import ChevronsUpDown
from .icons.kayak import Kayak
from .icons.badge_minus import BadgeMinus
from .icons.calendar_off import CalendarOff
from .icons.circle import Circle
from .icons.air_vent import AirVent
from .icons.phone_missed import PhoneMissed
from .icons.text_align_center import TextAlignCenter
from .icons.scale_3d import Scale3d
from .icons.corner_left_up import CornerLeftUp
from .icons.milk import Milk
from .icons.clipboard_pen import ClipboardPen
from .icons.file_up import FileUp
from .icons.copyright import Copyright
from .icons.picture_in_picture import PictureInPicture
from .icons.vault import Vault
from .icons.circle_power import CirclePower
from .icons.omega import Omega
from .icons.mailbox import Mailbox
from .icons.gitlab import Gitlab
from .icons.music import Music
from .icons.rectangle_ellipsis import RectangleEllipsis
from .icons.smartphone import Smartphone
from .icons.file_symlink import FileSymlink
from .icons.file_play import FilePlay
from .icons.alarm_clock_check import AlarmClockCheck
from .icons.handbag import Handbag
from .icons.door_closed_locked import DoorClosedLocked
from .icons.candy_off import CandyOff
from .icons.turntable import Turntable
from .icons.circuit_board import CircuitBoard
from .icons.folder_tree import FolderTree
from .icons.chart_gantt import ChartGantt
from .icons.equal import Equal
from .icons.grid_2x2_plus import Grid2x2Plus
from .icons.recycle import Recycle
from .icons.arrow_up_left import ArrowUpLeft
from .icons.clipboard_type import ClipboardType
from .icons.library import Library
from .icons.panel_top_close import PanelTopClose
from .icons.square_arrow_down import SquareArrowDown
from .icons.list_plus import ListPlus
from .icons.chevron_down import ChevronDown
from .icons.backpack import Backpack
from .icons.calendar_check_2 import CalendarCheck2
from .icons.cloud_check import CloudCheck
from .icons.heading import Heading
from .icons.hexagon import Hexagon
from .icons.non_binary import NonBinary
from .icons.strikethrough import Strikethrough
from .icons.calendar_fold import CalendarFold
from .icons.message_square_heart import MessageSquareHeart
from .icons.bird import Bird
from .icons.bot_message_square import BotMessageSquare
from .icons.sun_medium import SunMedium
from .icons.calendar_arrow_down import CalendarArrowDown
from .icons.badge_info import BadgeInfo
from .icons.shield_plus import ShieldPlus
from .icons.tickets import Tickets
from .icons.book_marked import BookMarked
from .icons.creative_commons import CreativeCommons
from .icons.shirt import Shirt
from .icons.dock import Dock
from .icons.signpost import Signpost
from .icons.door_closed import DoorClosed
from .icons.github import Github
from .icons.fold_horizontal import FoldHorizontal
from .icons.nfc import Nfc
from .icons.clipboard_paste import ClipboardPaste
from .icons.cone import Cone
from .icons.cooking_pot import CookingPot
from .icons.proportions import Proportions
from .icons.bring_to_front import BringToFront
from .icons.usb import Usb
from .icons.separator_vertical import SeparatorVertical
from .icons.hard_hat import HardHat
from .icons.cake_slice import CakeSlice
from .icons.sun_moon import SunMoon
from .icons.ticket import Ticket
from .icons.calendar_plus_2 import CalendarPlus2
from .icons.case_lower import CaseLower
from .icons.mail_question_mark import MailQuestionMark
from .icons.layout_template import LayoutTemplate
from .icons.panel_right_open import PanelRightOpen
from .icons.brackets import Brackets
from .icons.star_off import StarOff
from .icons.shrink import Shrink
from .icons.shrimp import Shrimp
from .icons.church import Church
from .icons.circle_percent import CirclePercent
from .icons.crop import Crop
from .icons.flask_round import FlaskRound
from .icons.brick_wall_fire import BrickWallFire
from .icons.cookie import Cookie
from .icons.chart_column_big import ChartColumnBig
from .icons.redo_2 import Redo2
from .icons.circle_slash_2 import CircleSlash2
from .icons.calendar_1 import Calendar1
from .icons.tag import Tag
from .icons.book_check import BookCheck
from .icons.octagon_pause import OctagonPause
from .icons.cup_soda import CupSoda
from .icons.option import Option
from .icons.sparkle import Sparkle
from .icons.briefcase import Briefcase
from .icons.circle_chevron_down import CircleChevronDown
from .icons.decimals_arrow_right import DecimalsArrowRight
from .icons.presentation import Presentation
from .icons.square_sigma import SquareSigma
from .icons.rotate_cw import RotateCw
from .icons.ellipsis_vertical import EllipsisVertical
from .icons.badge_plus import BadgePlus
from .icons.screen_share_off import ScreenShareOff
from .icons.square_play import SquarePlay
from .icons.align_horizontal_distribute_end import AlignHorizontalDistributeEnd
from .icons.file_clock import FileClock
from .icons.calendar_search import CalendarSearch
from .icons.image_down import ImageDown
from .icons.file_signal import FileSignal
from .icons.swatch_book import SwatchBook
from .icons.radius import Radius
from .icons.folder_sync import FolderSync
from .icons.panels_top_left import PanelsTopLeft
from .icons.headset import Headset
from .icons.circle_equal import CircleEqual
from .icons.dessert import Dessert
from .icons.carrot import Carrot
from .icons.receipt_euro import ReceiptEuro
from .icons.map import Map
from .icons.check_check import CheckCheck
from .icons.inbox import Inbox
from .icons.clock_plus import ClockPlus
from .icons.circle_alert import CircleAlert
from .icons.tv_minimal import TvMinimal
from .icons.power import Power
from .icons.a_large_small import ALargeSmall
from .icons.tent_tree import TentTree
from .icons.database import Database
from .icons.tickets_plane import TicketsPlane
from .icons.captions import Captions
from .icons.martini import Martini
from .icons.arrow_up_to_line import ArrowUpToLine
from .icons.monitor_down import MonitorDown
from .icons.badge_indian_rupee import BadgeIndianRupee
from .icons.camera_off import CameraOff
from .icons.fuel import Fuel
from .icons.satellite_dish import SatelliteDish
from .icons.bike import Bike
from .icons.decimals_arrow_left import DecimalsArrowLeft
from .icons.chart_no_axes_column import ChartNoAxesColumn
from .icons.swords import Swords
from .icons.message_square_off import MessageSquareOff
from .icons.scan_text import ScanText
from .icons.arrow_down_z_a import ArrowDownZA
from .icons.rat import Rat
from .icons.tornado import Tornado
from .icons.toggle_left import ToggleLeft
from .icons.file import File
from .icons.motorbike import Motorbike
from .icons.puzzle import Puzzle
from .icons.align_vertical_distribute_center import AlignVerticalDistributeCenter
from .icons.receipt_turkish_lira import ReceiptTurkishLira
from .icons.signal import Signal
from .icons.egg_off import EggOff
from .icons.arrow_up_1_0 import ArrowUp10
from .icons.baseline import Baseline
from .icons.vibrate_off import VibrateOff
from .icons.glass_water import GlassWater
from .icons.brain import Brain
from .icons.files import Files
from .icons.torus import Torus
from .icons.scan_search import ScanSearch
from .icons.helicopter import Helicopter
from .icons.square_dashed_bottom_code import SquareDashedBottomCode
from .icons.message_circle import MessageCircle
from .icons.message_square_dot import MessageSquareDot
from .icons.receipt_japanese_yen import ReceiptJapaneseYen
from .icons.voicemail import Voicemail
from .icons.octagon_minus import OctagonMinus
from .icons.messages_square import MessagesSquare
from .icons.ship_wheel import ShipWheel
from .icons.message_square_quote import MessageSquareQuote
from .icons.contrast import Contrast
from .icons.cuboid import Cuboid
from .icons.alarm_clock_plus import AlarmClockPlus
from .icons.monitor_pause import MonitorPause
from .icons.archive_x import ArchiveX
from .icons.terminal import Terminal
from .icons.move_diagonal import MoveDiagonal
from .icons.droplet_off import DropletOff
from .icons.file_scan import FileScan
from .icons.arrow_up_wide_narrow import ArrowUpWideNarrow
from .icons.banknote_arrow_down import BanknoteArrowDown
from .icons.move import Move
from .icons.maximize import Maximize
from .icons.between_vertical_start import BetweenVerticalStart
from .icons.laptop_minimal import LaptopMinimal
from .icons.radar import Radar
from .icons.logs import Logs
from .icons.sparkles import Sparkles
from .icons.lock_keyhole import LockKeyhole
from .icons.octagon_x import OctagonX
from .icons.scan_heart import ScanHeart
from .icons.folder_root import FolderRoot
from .icons.chevron_up import ChevronUp
from .icons.square_percent import SquarePercent
from .icons.haze import Haze
from .icons.folder_output import FolderOutput
from .icons.folder_symlink import FolderSymlink
from .icons.vibrate import Vibrate
from .icons.laugh import Laugh
from .icons.clock_fading import ClockFading
from .icons.scan_eye import ScanEye
from .icons.spade import Spade
from .icons.cloud_rain_wind import CloudRainWind
from .icons.sliders_vertical import SlidersVertical
from .icons.spline_pointer import SplinePointer
from .icons.undo_2 import Undo2
from .icons.step_back import StepBack
from .icons.flask_conical_off import FlaskConicalOff
from .icons.arrow_down_left import ArrowDownLeft
from .icons.list_filter_plus import ListFilterPlus
from .icons.file_text import FileText
from .icons.file_stack import FileStack
from .icons.folder_open import FolderOpen
from .icons.package_minus import PackageMinus
from .icons.droplet import Droplet
from .icons.whole_word import WholeWord
from .icons.paint_roller import PaintRoller
from .icons.zap_off import ZapOff
from .icons.clipboard_clock import ClipboardClock
from .icons.square_kanban import SquareKanban
from .icons.keyboard import Keyboard
from .icons.x import X
from .icons.chevrons_right_left import ChevronsRightLeft
from .icons.joystick import Joystick
from .icons.cigarette import Cigarette
from .icons.bath import Bath
from .icons.qr_code import QrCode
from .icons.dot import Dot
from .icons.file_search_corner import FileSearchCorner
from .icons.ice_cream_cone import IceCreamCone
from .icons.languages import Languages
from .icons.ampersands import Ampersands
from .icons.banknote_x import BanknoteX
from .icons.amphora import Amphora
from .icons.arrow_left_from_line import ArrowLeftFromLine
from .icons.bell_minus import BellMinus
from .icons.file_cog import FileCog
from .icons.wheat import Wheat
from .icons.eye_closed import EyeClosed
from .icons.cable_car import CableCar
from .icons.arrow_up_narrow_wide import ArrowUpNarrowWide
from .icons.lock import Lock
from .icons.dice_2 import Dice2
from .icons.log_in import LogIn
from .icons.squircle import Squircle
from .icons.cloud_upload import CloudUpload
from .icons.shield_ellipsis import ShieldEllipsis
from .icons.ban import Ban
from .icons.smartphone_nfc import SmartphoneNfc
from .icons.list_video import ListVideo
from .icons.text_select import TextSelect
from .icons.shopping_bag import ShoppingBag
from .icons.divide import Divide
from .icons.piggy_bank import PiggyBank
from .icons.battery_warning import BatteryWarning
from .icons.wallet_minimal import WalletMinimal
from .icons.circle_dollar_sign import CircleDollarSign
from .icons.milk_off import MilkOff
from .icons.rotate_ccw_key import RotateCcwKey
from .icons.square_parking import SquareParking
from .icons.refresh_ccw_dot import RefreshCcwDot
from .icons.tally_2 import Tally2
from .icons.shell import Shell
from .icons.banknote_arrow_up import BanknoteArrowUp
from .icons.repeat_2 import Repeat2
from .icons.pilcrow import Pilcrow
from .icons.circle_dot_dashed import CircleDotDashed
from .icons.cloud_drizzle import CloudDrizzle
from .icons.copy_minus import CopyMinus
from .icons.spline import Spline
from .icons.refresh_cw import RefreshCw
from .icons.pen import Pen
from .icons.user_pen import UserPen
from .icons.rectangle_circle import RectangleCircle
from .icons.plane import Plane
from .icons.align_vertical_space_between import AlignVerticalSpaceBetween
from .icons.chevron_right import ChevronRight
from .icons.tally_3 import Tally3
from .icons.clipboard import Clipboard
from .icons.equal_not import EqualNot
from .icons.package import Package
from .icons.shield_user import ShieldUser
from .icons.mars import Mars
from .icons.instagram import Instagram
from .icons.mail_warning import MailWarning
from .icons.euro import Euro
from .icons.link import Link
from .icons.square_chevron_left import SquareChevronLeft
from .icons.globe_lock import GlobeLock
from .icons.dice_3 import Dice3
from .icons.hand_platter import HandPlatter
from .icons.video_off import VideoOff
from .icons.user_round_plus import UserRoundPlus
from .icons.gpu import Gpu
from .icons.key import Key
from .icons.square_activity import SquareActivity
from .icons.shrub import Shrub
from .icons.sailboat import Sailboat
from .icons.square_slash import SquareSlash
from .icons.brain_cog import BrainCog
from .icons.meh import Meh
from .icons.sliders_horizontal import SlidersHorizontal
from .icons.door_open import DoorOpen
from .icons.corner_down_right import CornerDownRight
from .icons.beaker import Beaker
from .icons.list_todo import ListTodo
from .icons.cloud_sun import CloudSun
from .icons.arrow_right import ArrowRight
from .icons.store import Store
from .icons.antenna import Antenna
from .icons.chevron_first import ChevronFirst
from .icons.wheat_off import WheatOff
from .icons.aperture import Aperture
from .icons.calendar_plus import CalendarPlus
from .icons.brush import Brush
from .icons.thermometer_snowflake import ThermometerSnowflake
from .icons.clover import Clover
from .icons.concierge_bell import ConciergeBell
from .icons.log_out import LogOut
from .icons.unfold_horizontal import UnfoldHorizontal
from .icons.file_spreadsheet import FileSpreadsheet
from .icons.square_radical import SquareRadical
from .icons.circle_play import CirclePlay
from .icons.square_arrow_up import SquareArrowUp
from .icons.telescope import Telescope
from .icons.ship import Ship
from .icons.ear_off import EarOff
from .icons.worm import Worm
from .icons.wallpaper import Wallpaper
from .icons.ambulance import Ambulance
from .icons.space import Space
from .icons.file_input import FileInput
from .icons.book_dashed import BookDashed
from .icons.list_indent_increase import ListIndentIncrease
from .icons.hand_grab import HandGrab
from .icons.stretch_vertical import StretchVertical
from .icons.calendar_check import CalendarCheck
from .icons.diff import Diff
from .icons.shower_head import ShowerHead
from .icons.square_pen import SquarePen
from .icons.arrow_down_up import ArrowDownUp
from .icons.git_pull_request import GitPullRequest
from .icons.minimize import Minimize
from .icons.group import Group
from .icons.settings import Settings
from .icons.cloud_snow import CloudSnow
from .icons.notepad_text_dashed import NotepadTextDashed
from .icons.calendar_x_2 import CalendarX2
from .icons.cassette_tape import CassetteTape
from .icons.thumbs_down import ThumbsDown
from .icons.dice_1 import Dice1
from .icons.move_down_left import MoveDownLeft
from .icons.vote import Vote
from .icons.house_heart import HouseHeart
from .icons.bot_off import BotOff
from .icons.type import Type
from .icons.square_dashed_mouse_pointer import SquareDashedMousePointer
from .icons.bow_arrow import BowArrow
from .icons.square_menu import SquareMenu
from .icons.mouse_pointer_click import MousePointerClick
from .icons.regex import Regex
from .icons.square_check_big import SquareCheckBig
from .icons.badge_question_mark import BadgeQuestionMark
from .icons.loader_circle import LoaderCircle
from .icons.popsicle import Popsicle
from .icons.lamp_floor import LampFloor
from .icons.utensils import Utensils
from .icons.map_pin_minus import MapPinMinus
from .icons.rose import Rose
from .icons.archive import Archive
from .icons.bean import Bean
from .icons.panels_right_bottom import PanelsRightBottom
from .icons.equal_approximately import EqualApproximately
from .icons.message_square_text import MessageSquareText
from .icons.refresh_cw_off import RefreshCwOff
from .icons.phone_outgoing import PhoneOutgoing
from .icons.tally_1 import Tally1
from .icons.arrow_up_from_dot import ArrowUpFromDot
from .icons.candy import Candy
from .icons.pocket import Pocket
from .icons.repeat_1 import Repeat1
from .icons.magnet import Magnet
from .icons.circle_parking import CircleParking
from .icons.mail import Mail
from .icons.school import School
from .icons.chart_spline import ChartSpline
from .icons.arrow_big_right import ArrowBigRight
from .icons.panel_top_bottom_dashed import PanelTopBottomDashed
from .icons.shield import Shield
from .icons.download import Download
from .icons.kanban import Kanban
from .icons.file_volume import FileVolume
from .icons.expand import Expand
from .icons.gallery_vertical_end import GalleryVerticalEnd
from .icons.disc_album import DiscAlbum
from .icons.pin import Pin
from .icons.arrow_up_a_z import ArrowUpAZ
from .icons.bandage import Bandage
from .icons.square_check import SquareCheck
from .icons.import_ import Import
from .icons.webcam import Webcam
from .icons.waves_arrow_up import WavesArrowUp
from .icons.phone_forwarded import PhoneForwarded
from .icons.bell_plus import BellPlus
from .icons.square_dot import SquareDot
from .icons.corner_right_down import CornerRightDown
from .icons.square_divide import SquareDivide
from .icons.book_open import BookOpen
from .icons.forklift import Forklift
from .icons.calendar_cog import CalendarCog
from .icons.castle import Castle
from .icons.orbit import Orbit
from .icons.parentheses import Parentheses
from .icons.projector import Projector
from .icons.pilcrow_right import PilcrowRight
from .icons.server import Server
from .icons.user_round_check import UserRoundCheck
from .icons.bolt import Bolt
from .icons.tv import Tv
from .icons.message_square_dashed import MessageSquareDashed
from .icons.droplets import Droplets
from .icons.skip_forward import SkipForward
from .icons.archive_restore import ArchiveRestore
from .icons.volume import Volume
from .icons.lamp_wall_up import LampWallUp
from .icons.drumstick import Drumstick
from .icons.user_plus import UserPlus
from .icons.wifi_zero import WifiZero
from .icons.battery_medium import BatteryMedium
from .icons.book_a import BookA
from .icons.text_align_justify import TextAlignJustify
from .icons.battery_charging import BatteryCharging
from .icons.shapes import Shapes
from .icons.solar_panel import SolarPanel
from .icons.folders import Folders
from .icons.satellite import Satellite
from .icons.list_minus import ListMinus
from .icons.circle_arrow_left import CircleArrowLeft
from .icons.bookmark_minus import BookmarkMinus
from .icons.list_chevrons_up_down import ListChevronsUpDown
from .icons.heater import Heater
from .icons.layers import Layers
from .icons.earth_lock import EarthLock
from .icons.spool import Spool
from .icons.square_parking_off import SquareParkingOff
from .icons.dna import Dna
from .icons.mouse_off import MouseOff
from .icons.slash import Slash
from .icons.radio import Radio
from .icons.align_center_vertical import AlignCenterVertical
from .icons.alarm_clock import AlarmClock
from .icons.alarm_clock_off import AlarmClockOff
from .icons.book import Book
from .icons.keyboard_music import KeyboardMusic
from .icons.hotel import Hotel
from .icons.book_text import BookText
from .icons.variable import Variable
from .icons.touchpad_off import TouchpadOff
from .icons.bitcoin import Bitcoin
from .icons.message_square_x import MessageSquareX
from .icons.car_front import CarFront
from .icons.alarm_smoke import AlarmSmoke
from .icons.dice_4 import Dice4
from .icons.skull import Skull
from .icons.mail_minus import MailMinus
from .icons.bot import Bot
from .icons.plug import Plug
from .icons.shield_x import ShieldX
from .icons.train_track import TrainTrack
from .icons.goal import Goal
from .icons.square_chart_gantt import SquareChartGantt
from .icons.file_chart_column import FileChartColumn
from .icons.folder_archive import FolderArchive
from .icons.signal_high import SignalHigh
from .icons.user_minus import UserMinus
from .icons.plane_landing import PlaneLanding
from .icons.wallet import Wallet
from .icons.circle_check import CircleCheck
from .icons.tally_4 import Tally4
from .icons.file_image import FileImage
from .icons.square_dashed_bottom import SquareDashedBottom
from .icons.panel_top_open import PanelTopOpen
from .icons.bell import Bell
from .icons.git_branch import GitBranch
from .icons.square_m import SquareM
from .icons.coffee import Coffee
from .icons.funnel import Funnel
from .icons.panel_left_dashed import PanelLeftDashed
from .icons.code import Code
from .icons.rail_symbol import RailSymbol
from .icons.circle_divide import CircleDivide
from .icons.cake import Cake
from .icons.spell_check_2 import SpellCheck2
from .icons.shredder import Shredder
from .icons.user_lock import UserLock
from .icons.settings_2 import Settings2
from .icons.tally_5 import Tally5
from .icons.chart_bar_decreasing import ChartBarDecreasing
from .icons.message_circle_dashed import MessageCircleDashed
from .icons.cloud_moon_rain import CloudMoonRain
from .icons.radio_tower import RadioTower
from .icons.thermometer import Thermometer
from .icons.cast import Cast
from .icons.milestone import Milestone
from .icons.move_3d import Move3d
from .icons.flag import Flag
from .icons.podcast import Podcast
from .icons.tv_minimal_play import TvMinimalPlay
from .icons.git_fork import GitFork
from .icons.eye_off import EyeOff
from .icons.dice_5 import Dice5
from .icons.tram_front import TramFront
from .icons.battery import Battery
from .icons.blinds import Blinds
from .icons.chess_king import ChessKing
from .icons.arrow_left_to_line import ArrowLeftToLine
from .icons.newspaper import Newspaper
from .icons.clipboard_pen_line import ClipboardPenLine
from .icons.snowflake import Snowflake
from .icons.disc import Disc
from .icons.step_forward import StepForward
from .icons.bomb import Bomb
from .icons.piano import Piano
from .icons.book_copy import BookCopy
from .icons.map_pin_plus import MapPinPlus
from .icons.arrow_up_0_1 import ArrowUp01
from .icons.database_zap import DatabaseZap
from .icons.git_branch_minus import GitBranchMinus
from .icons.rotate_3d import Rotate3d
from .icons.star_half import StarHalf
from .icons.switch_camera import SwitchCamera
from .icons.image_plus import ImagePlus
from .icons.square_round_corner import SquareRoundCorner
from .icons.pencil_ruler import PencilRuler
from .icons.container import Container
from .icons.ruler import Ruler
from .icons.turtle import Turtle
from .icons.frown import Frown
from .icons.tree_pine import TreePine
from .icons.audio_lines import AudioLines
from .icons.circle_slash import CircleSlash
from .icons.notebook_text import NotebookText
from .icons.layout_dashboard import LayoutDashboard
from .icons.cpu import Cpu
from .icons.align_end_horizontal import AlignEndHorizontal
from .icons.flame_kindling import FlameKindling
from .icons.cloud_alert import CloudAlert
from .icons.clipboard_list import ClipboardList
from .icons.biohazard import Biohazard
from .icons.folder_x import FolderX
from .icons.book_open_check import BookOpenCheck
from .icons.list_ordered import ListOrdered
from .icons.factory import Factory
from .icons.bold import Bold
from .icons.tablets import Tablets
from .icons.wifi_low import WifiLow
from .icons.fence import Fence
from .icons.trophy import Trophy
from .icons.scan_qr_code import ScanQrCode
from .icons.hash import Hash
from .icons.shield_minus import ShieldMinus
from .icons.link_2_off import Link2Off
from .icons.dam import Dam
from .icons.share_2 import Share2
from .icons.battery_full import BatteryFull
from .icons.plus import Plus
from .icons.monitor_stop import MonitorStop
from .icons.panel_bottom import PanelBottom
from .icons.clipboard_minus import ClipboardMinus
from .icons.check import Check
from .icons.align_vertical_justify_end import AlignVerticalJustifyEnd
from .icons.map_minus import MapMinus
from .icons.rabbit import Rabbit
from .icons.plug_zap import PlugZap
from .icons.nut import Nut
from .icons.mail_plus import MailPlus
from .icons.move_down_right import MoveDownRight
from .icons.rotate_ccw import RotateCcw
from .icons.circle_star import CircleStar
from .icons.heart_crack import HeartCrack
from .icons.flip_horizontal_2 import FlipHorizontal2
from .icons.hard_drive import HardDrive
from .icons.between_horizontal_end import BetweenHorizontalEnd
from .icons.tent import Tent
from .icons.trending_up_down import TrendingUpDown
from .icons.hard_drive_download import HardDriveDownload
from .icons.circle_fading_plus import CircleFadingPlus
from .icons.pen_line import PenLine
from .icons.align_vertical_space_around import AlignVerticalSpaceAround
from .icons.hospital import Hospital
from .icons.case_sensitive import CaseSensitive
from .icons.focus import Focus
from .icons.bluetooth import Bluetooth
from .icons.align_end_vertical import AlignEndVertical
from .icons.square_split_vertical import SquareSplitVertical
from .icons.headphones import Headphones
from .icons.map_pin_x import MapPinX
from .icons.table_properties import TableProperties
from .icons.git_pull_request_create_arrow import GitPullRequestCreateArrow
from .icons.folder_git_2 import FolderGit2
from .icons.book_alert import BookAlert
from .icons.square_x import SquareX
from .icons.square_asterisk import SquareAsterisk
from .icons.rss import Rss
from .icons.table_cells_split import TableCellsSplit
from .icons.flower_2 import Flower2
from .icons.landmark import Landmark
from .icons.wifi import Wifi
from .icons.corner_up_left import CornerUpLeft
from .icons.file_archive import FileArchive
from .icons.square_arrow_up_left import SquareArrowUpLeft
from .icons.arrow_down_from_line import ArrowDownFromLine
from .icons.watch import Watch
from .icons.square_arrow_down_right import SquareArrowDownRight
from .icons.scale import Scale
from .icons.dice_6 import Dice6
from .icons.message_square_more import MessageSquareMore
from .icons.ampersand import Ampersand
from .icons.dna_off import DnaOff
from .icons.square_arrow_out_up_right import SquareArrowOutUpRight
from .icons.hand_coins import HandCoins
from .icons.roller_coaster import RollerCoaster
from .icons.monitor_smartphone import MonitorSmartphone
from .icons.venus import Venus
from .icons.list_indent_decrease import ListIndentDecrease
from .icons.git_commit_vertical import GitCommitVertical
from .icons.soap_dispenser_droplet import SoapDispenserDroplet
from .icons.info import Info
from .icons.blocks import Blocks
from .icons.popcorn import Popcorn
from .icons.file_badge import FileBadge
from .icons.badge_dollar_sign import BadgeDollarSign
from .icons.user_x import UserX
from .icons.navigation_off import NavigationOff
from .icons.key_square import KeySquare
from .icons.ticket_minus import TicketMinus
from .icons.dog import Dog
from .icons.layout_panel_left import LayoutPanelLeft
from .icons.fan import Fan
from .icons.radio_receiver import RadioReceiver
from .icons.loader import Loader
from .icons.palette import Palette
from .icons.pilcrow_left import PilcrowLeft
from .icons.file_x_corner import FileXCorner
from .icons.diamond_plus import DiamondPlus
from .icons.circle_arrow_out_down_left import CircleArrowOutDownLeft
from .icons.receipt_swiss_franc import ReceiptSwissFranc
from .icons.package_2 import Package2
from .icons.chart_no_axes_combined import ChartNoAxesCombined
from .icons.file_plus_corner import FilePlusCorner
from .icons.funnel_x import FunnelX
from .icons.case_upper import CaseUpper
from .icons.volleyball import Volleyball
from .icons.id_card_lanyard import IdCardLanyard
from .icons.refresh_ccw import RefreshCcw
from .icons.cloud_fog import CloudFog
from .icons.git_branch_plus import GitBranchPlus
from .icons.file_x import FileX
from .icons.heading_1 import Heading1
from .icons.hop import Hop
from .icons.folder_up import FolderUp
from .icons.soup import Soup
from .icons.folder_plus import FolderPlus
from .icons.badge_russian_ruble import BadgeRussianRuble
from .icons.git_merge import GitMerge
from .icons.japanese_yen import JapaneseYen
from .icons.grip_horizontal import GripHorizontal
from .icons.list_x import ListX
from .icons.shield_half import ShieldHalf
from .icons.mic import Mic
from .icons.venetian_mask import VenetianMask
from .icons.rainbow import Rainbow
from .icons.git_pull_request_arrow import GitPullRequestArrow
from .icons.copy import Copy
from .icons.smile_plus import SmilePlus
from .icons.fish import Fish
from .icons.move_up_left import MoveUpLeft
from .icons.card_sim import CardSim
from .icons.list_tree import ListTree
from .icons.zoom_in import ZoomIn
from .icons.circle_chevron_up import CircleChevronUp
from .icons.circle_arrow_out_down_right import CircleArrowOutDownRight
from .icons.search_check import SearchCheck
from .icons.signature import Signature
from .icons.arrow_down_to_line import ArrowDownToLine
from .icons.battery_plus import BatteryPlus
from .icons.glasses import Glasses
from .icons.coins import Coins
from .icons.align_start_vertical import AlignStartVertical
from .icons.arrows_up_from_line import ArrowsUpFromLine
from .icons.user_star import UserStar
from .icons.snail import Snail
from .icons.library_big import LibraryBig
from .icons.bookmark_x import BookmarkX
from .icons.book_key import BookKey
from .icons.panel_left import PanelLeft
from .icons.test_tube_diagonal import TestTubeDiagonal
from .icons.origami import Origami
from .icons.square_library import SquareLibrary
from .icons.message_circle_off import MessageCircleOff
from .icons.square_user_round import SquareUserRound
from .icons.wand_sparkles import WandSparkles
from .icons.text_quote import TextQuote
from .icons.caravan import Caravan
from .icons.badge_cent import BadgeCent
from .icons.panel_top_dashed import PanelTopDashed
from .icons.notebook_tabs import NotebookTabs
from .icons.test_tubes import TestTubes
from .icons.fire_extinguisher import FireExtinguisher
from .icons.egg_fried import EggFried
from .icons.flag_triangle_left import FlagTriangleLeft
from .icons.text_cursor import TextCursor
from .icons.image import Image
from .icons.file_question_mark import FileQuestionMark
from .icons.panel_bottom_open import PanelBottomOpen
from .icons.maximize_2 import Maximize2
from .icons.vector_square import VectorSquare
from .icons.lightbulb import Lightbulb
from .icons.server_off import ServerOff
from .icons.arrow_big_left_dash import ArrowBigLeftDash
from .icons.image_play import ImagePlay
from .icons.sunset import Sunset
from .icons.save import Save
from .icons.smile import Smile
from .icons.search_code import SearchCode
from .icons.lamp import Lamp
from .icons.siren import Siren
from .icons.images import Images
from .icons.scan import Scan
from .icons.navigation import Navigation
from .icons.circle_pound_sterling import CirclePoundSterling
from .icons.cloud_lightning import CloudLightning
from .icons.turkish_lira import TurkishLira
from .icons.user_round_pen import UserRoundPen
from .icons.square_dashed_top_solid import SquareDashedTopSolid
from .icons.citrus import Citrus
from .icons.message_square_diff import MessageSquareDiff
from .icons.bell_electric import BellElectric
from .icons.ham import Ham
from .icons.square_square import SquareSquare
from .icons.monitor_play import MonitorPlay
from .icons.barrel import Barrel
from .icons.badge_pound_sterling import BadgePoundSterling
from .icons.hard_drive_upload import HardDriveUpload
from .icons.app_window import AppWindow
from .icons.badge import Badge
from .icons.theater import Theater
from .icons.paperclip import Paperclip
from .icons.wifi_sync import WifiSync
from .icons.heading_2 import Heading2
from .icons.clock_check import ClockCheck
from .icons.square_scissors import SquareScissors
from .icons.fast_forward import FastForward
from .icons.flag_triangle_right import FlagTriangleRight
from .icons.calendar_range import CalendarRange
from .icons.contact_round import ContactRound
from .icons.syringe import Syringe
from .icons.spotlight import Spotlight
from .icons.search_slash import SearchSlash
from .icons.sticker import Sticker
from .icons.award import Award
from .icons.panel_right_dashed import PanelRightDashed
from .icons.squares_exclude import SquaresExclude
from .icons.zoom_out import ZoomOut
from .icons.square_arrow_out_up_left import SquareArrowOutUpLeft
from .icons.box import Box
from .icons.thumbs_up import ThumbsUp
from .icons.superscript import Superscript
from .icons.ticket_percent import TicketPercent
from .icons.battery_low import BatteryLow
from .icons.touchpad import Touchpad
from .icons.speech import Speech
from .icons.percent import Percent
from .icons.square_chevron_down import SquareChevronDown
from .icons.square import Square
from .icons.crown import Crown
from .icons.bluetooth_searching import BluetoothSearching
from .icons.timer_reset import TimerReset
from .icons.stethoscope import Stethoscope
from .icons.eclipse import Eclipse
from .icons.donut import Donut
from .icons.candy_cane import CandyCane
from .icons.play import Play
from .icons.folder_heart import FolderHeart
from .icons.pen_off import PenOff
from .icons.file_check import FileCheck
from .icons.leafy_green import LeafyGreen
from .icons.circle_small import CircleSmall
from .icons.tangent import Tangent
from .icons.book_audio import BookAudio
from .icons.table import Table
from .icons.split import Split
from .icons.send import Send
from .icons.barcode import Barcode
from .icons.file_headphone import FileHeadphone
from .icons.videotape import Videotape
from .icons.scooter import Scooter
from .icons.scroll import Scroll
from .icons.phone_call import PhoneCall
from .icons.columns_4 import Columns4
from .icons.rectangle_goggles import RectangleGoggles
from .icons.baggage_claim import BaggageClaim
from .icons.message_square_lock import MessageSquareLock
from .icons.circle_arrow_out_up_right import CircleArrowOutUpRight
from .icons.radiation import Radiation
from .icons.speaker import Speaker
from .icons.user_round_search import UserRoundSearch
from .icons.undo_dot import UndoDot
from .icons.facebook import Facebook
from .icons.codesandbox import Codesandbox
from .icons.file_down import FileDown
from .icons.badge_check import BadgeCheck
from .icons.baby import Baby
from .icons.smartphone_charging import SmartphoneCharging
from .icons.book_plus import BookPlus
from .icons.unplug import Unplug
from .icons.heading_3 import Heading3
from .icons.circle_question_mark import CircleQuestionMark
from .icons.folder_code import FolderCode
from .icons.bluetooth_connected import BluetoothConnected
from .icons.table_of_contents import TableOfContents
from .icons.camera import Camera
from .icons.link_2 import Link2
from .icons.printer import Printer
from .icons.list_collapse import ListCollapse
from .icons.workflow import Workflow
from .icons.trees import Trees
from .icons.panel_left_close import PanelLeftClose
from .icons.git_graph import GitGraph
from .icons.redo import Redo
from .icons.captions_off import CaptionsOff
from .icons.club import Club
from .icons.folder_minus import FolderMinus
from .icons.move_diagonal_2 import MoveDiagonal2
from .icons.combine import Combine
from .icons.arrow_up_right import ArrowUpRight
from .icons.truck import Truck
from .icons.layout_panel_top import LayoutPanelTop
from .icons.book_search import BookSearch
from .icons.life_buoy import LifeBuoy
from .icons.user_search import UserSearch
from .icons.square_user import SquareUser
from .icons.table_columns_split import TableColumnsSplit
from .icons.between_horizontal_start import BetweenHorizontalStart
from .icons.pickaxe import Pickaxe
from .icons.map_pin_x_inside import MapPinXInside
from .icons.package_x import PackageX
from .icons.pen_tool import PenTool
from .icons.alarm_clock_minus import AlarmClockMinus
from .icons.panels_left_bottom import PanelsLeftBottom
from .icons.circle_gauge import CircleGauge
from .icons.folder_cog import FolderCog
from .icons.at_sign import AtSign
from .icons.rotate_ccw_square import RotateCcwSquare
from .icons.text_align_end import TextAlignEnd
from .icons.map_pin_pen import MapPinPen
from .icons.circle_arrow_right import CircleArrowRight
from .icons.shield_alert import ShieldAlert
from .icons.map_pin_off import MapPinOff
from .icons.list_restart import ListRestart
from .icons.house_wifi import HouseWifi
from .icons.hand_metal import HandMetal
from .icons.egg import Egg
from .icons.car_taxi_front import CarTaxiFront
from .icons.square_mouse_pointer import SquareMousePointer
from .icons.hand_fist import HandFist
from .icons.brick_wall_shield import BrickWallShield
from .icons.monitor_x import MonitorX
from .icons.square_terminal import SquareTerminal
from .icons.grid_2x2_check import Grid2x2Check
from .icons.hat_glasses import HatGlasses
from .icons.bus import Bus
from .icons.file_pen_line import FilePenLine
from .icons.book_heart import BookHeart
from .icons.infinity import Infinity
from .icons.gem import Gem
from .icons.git_compare import GitCompare
from .icons.receipt_cent import ReceiptCent
from .icons.feather import Feather
from .icons.webhook_off import WebhookOff
from .icons.trash import Trash
from .icons.monitor_cog import MonitorCog
from .icons.squares_subtract import SquaresSubtract
from .icons.tree_palm import TreePalm
from .icons.chart_bar import ChartBar
from .icons.arrow_down_1_0 import ArrowDown10
from .icons.database_backup import DatabaseBackup
from .icons.bubbles import Bubbles
from .icons.armchair import Armchair
from .icons.wifi_off import WifiOff
from .icons.truck_electric import TruckElectric
from .icons.transgender import Transgender
from .icons.user_round import UserRound
from .icons.ungroup import Ungroup
from .icons.toilet import Toilet
from .icons.book_lock import BookLock
from .icons.leaf import Leaf
from .icons.arrow_down_wide_narrow import ArrowDownWideNarrow
from .icons.network import Network
from .icons.app_window_mac import AppWindowMac
from .icons.arrow_up_z_a import ArrowUpZA
from .icons.scan_barcode import ScanBarcode
from .icons.house_plus import HousePlus
from .icons.corner_left_down import CornerLeftDown
from .icons.map_pin_minus_inside import MapPinMinusInside
from .icons.message_square_plus import MessageSquarePlus
from .icons.folder_clock import FolderClock
from .icons.map_pin_house import MapPinHouse
from .icons.paintbrush_vertical import PaintbrushVertical
from .icons.dollar_sign import DollarSign
from .icons.triangle_right import TriangleRight
from .icons.indian_rupee import IndianRupee
from .icons.construction import Construction
from .icons.circle_plus import CirclePlus
from .icons.graduation_cap import GraduationCap
from .icons.scan_face import ScanFace
from .icons.fish_symbol import FishSymbol
from .icons.monitor_speaker import MonitorSpeaker
from .icons.guitar import Guitar
from .icons.form import Form
from .icons.star import Star
from .icons.lock_keyhole_open import LockKeyholeOpen
from .icons.monitor_check import MonitorCheck
from .icons.sandwich import Sandwich
from .icons.chef_hat import ChefHat
from .icons.wifi_pen import WifiPen
from .icons.heading_6 import Heading6
from .icons.cloud_off import CloudOff
from .icons.save_all import SaveAll
from .icons.file_user import FileUser
from .icons.sun import Sun
from .icons.wrench import Wrench
from .icons.signal_medium import SignalMedium
from .icons.pyramid import Pyramid
from .icons.book_minus import BookMinus
from .icons.gauge import Gauge
from .icons.chart_column import ChartColumn
from .icons.message_square import MessageSquare
from .icons.bug_play import BugPlay
from .icons.book_x import BookX
from .icons.heading_4 import Heading4
from .icons.chart_column_increasing import ChartColumnIncreasing
from .icons.pizza import Pizza
from .icons.unlink import Unlink
from .icons.philippine_peso import PhilippinePeso
from .icons.chevrons_down_up import ChevronsDownUp
from .icons.bone import Bone
from .icons.flashlight_off import FlashlightOff
from .icons.grid_3x2 import Grid3x2
from .icons.anchor import Anchor
from .icons.hammer import Hammer
from .icons.chevrons_left_right_ellipsis import ChevronsLeftRightEllipsis
from .icons.file_braces_corner import FileBracesCorner
from .icons.plug_2 import Plug2
from .icons.notebook_pen import NotebookPen
from .icons.chevrons_up import ChevronsUp
from .icons.columns_3 import Columns3
from .icons.move_horizontal import MoveHorizontal
from .icons.highlighter import Highlighter
from .icons.square_arrow_up_right import SquareArrowUpRight
from .icons.tablet_smartphone import TabletSmartphone
from .icons.circle_stop import CircleStop
from .icons.twitch import Twitch
from .icons.chart_no_axes_column_decreasing import ChartNoAxesColumnDecreasing
from .icons.chart_pie import ChartPie
from .icons.banana import Banana
from .icons.tree_deciduous import TreeDeciduous
from .icons.folder_lock import FolderLock
from .icons.locate import Locate
from .icons.list_music import ListMusic
from .icons.bug import Bug
from .icons.panel_top import PanelTop
from .icons.message_square_code import MessageSquareCode
from .icons.mail_open import MailOpen
from .icons.youtube import Youtube
from .icons.file_chart_line import FileChartLine
from .icons.shield_question_mark import ShieldQuestionMark
from .icons.chevrons_left_right import ChevronsLeftRight
from .icons.bookmark_plus import BookmarkPlus
from .icons.a_arrow_up import AArrowUp
from .icons.file_code_corner import FileCodeCorner
from .icons.tower_control import TowerControl
from .icons.book_up import BookUp
from .icons.pocket_knife import PocketKnife
from .icons.shovel import Shovel
from .icons.compass import Compass
from .icons.file_minus_corner import FileMinusCorner
from .icons.align_horizontal_justify_end import AlignHorizontalJustifyEnd
from .icons.server_crash import ServerCrash
from .icons.traffic_cone import TrafficCone
from .icons.triangle_dashed import TriangleDashed
from .icons.plane_takeoff import PlaneTakeoff
from .icons.house_plug import HousePlug
from .icons.folder_kanban import FolderKanban
from .icons.mail_search import MailSearch
from .icons.image_up import ImageUp
from .icons.cloud_moon import CloudMoon
from .icons.waves_arrow_down import WavesArrowDown
from .icons.columns_2 import Columns2
from .icons.warehouse import Warehouse
from .icons.calendar_arrow_up import CalendarArrowUp
from .icons.rotate_cw_square import RotateCwSquare
from .icons.square_function import SquareFunction
from .icons.frame import Frame
from .icons.credit_card import CreditCard
from .icons.circle_arrow_down import CircleArrowDown
from .icons.calendars import Calendars
from .icons.table_2 import Table2
from .icons.copyleft import Copyleft
from .icons.grid_3x3 import Grid3x3
from .icons.message_circle_question_mark import MessageCircleQuestionMark
from .icons.ticket_x import TicketX
from .icons.align_vertical_justify_start import AlignVerticalJustifyStart
from .icons.heart_off import HeartOff
from .icons.cylinder import Cylinder
from .icons.computer import Computer
from .icons.book_type import BookType
from .icons.pill_bottle import PillBottle
from .icons.heading_5 import Heading5
from .icons.thermometer_sun import ThermometerSun
from .icons.locate_off import LocateOff
from .icons.reply_all import ReplyAll
from .icons.pencil import Pencil
from .icons.cloud_rain import CloudRain
from .icons.mars_stroke import MarsStroke
from .icons.send_to_back import SendToBack
from .icons.git_pull_request_closed import GitPullRequestClosed
from .icons.arrow_big_right_dash import ArrowBigRightDash
from .icons.wind_arrow_down import WindArrowDown
from .icons.align_vertical_distribute_start import AlignVerticalDistributeStart
from .icons.book_down import BookDown
from .icons.pound_sterling import PoundSterling
from .icons.monitor_up import MonitorUp
from .icons.mouse_pointer_2_off import MousePointer2Off
from .icons.bean_off import BeanOff
from .icons.trash_2 import Trash2
from .icons.circle_user import CircleUser
from .icons.skip_back import SkipBack
from .icons.file_plus import FilePlus
from .icons.scroll_text import ScrollText
from .icons.diamond import Diamond
from .icons.delete import Delete
from .icons.command import Command
from .icons.package_check import PackageCheck
from .icons.align_center_horizontal import AlignCenterHorizontal
from .icons.clock import Clock
from .icons.bell_ring import BellRing
from .icons.remove_formatting import RemoveFormatting
from .icons.router import Router
from .icons.footprints import Footprints
from .icons.octagon import Octagon
from .icons.arrow_big_left import ArrowBigLeft
from .icons.table_rows_split import TableRowsSplit
from .icons.phone import Phone
from .icons.circle_x import CircleX
from .icons.land_plot import LandPlot
from .icons.align_horizontal_justify_center import AlignHorizontalJustifyCenter
from .icons.sun_snow import SunSnow
from .icons.chart_bar_increasing import ChartBarIncreasing
from .icons.image_off import ImageOff
from .icons.clock_alert import ClockAlert
from .icons.umbrella_off import UmbrellaOff
from .icons.arrow_down_a_z import ArrowDownAZ
from .icons.panel_left_open import PanelLeftOpen
from .icons.brain_circuit import BrainCircuit
from .icons.move_vertical import MoveVertical
from .icons.users_round import UsersRound
from .icons.salad import Salad
from .icons.dumbbell import Dumbbell
from .icons.tractor import Tractor
from .icons.waves import Waves
from .icons.folder_closed import FolderClosed
from .icons.eye import Eye
from .icons.user_round_cog import UserRoundCog
from .icons.mouse_pointer_ban import MousePointerBan
from .icons.drone import Drone
from .icons.headphone_off import HeadphoneOff
from .icons.badge_alert import BadgeAlert
from .icons.server_cog import ServerCog
from .icons.pipette import Pipette
from .icons.phone_off import PhoneOff
from .icons.flower import Flower
from .icons.banknote import Banknote
from .icons.ruler_dimension_line import RulerDimensionLine
from .icons.sprout import Sprout
from .icons.brick_wall import BrickWall
from .icons.copy_check import CopyCheck
from .icons.rectangle_vertical import RectangleVertical
from .icons.pill import Pill
from .icons.codepen import Codepen
from .icons.dribbble import Dribbble
from .icons.chart_bar_big import ChartBarBig
from .icons.message_circle_plus import MessageCirclePlus
from .icons.axe import Axe
from .icons.square_plus import SquarePlus
from .icons.gift import Gift
from .icons.receipt_russian_ruble import ReceiptRussianRuble
from .icons.package_plus import PackagePlus
from .icons.external_link import ExternalLink
from .icons.currency import Currency
from .icons.wand import Wand
from .icons.file_music import FileMusic
from .icons.car import Car
from .icons.zap import Zap
from .icons.trello import Trello
from .icons.list_checks import ListChecks
from .icons.square_pause import SquarePause
from .icons.message_square_reply import MessageSquareReply
from .icons.badge_x import BadgeX
from .icons.building_2 import Building2
from .icons.list_chevrons_down_up import ListChevronsDownUp
from .icons.chart_no_axes_gantt import ChartNoAxesGantt
from .icons.moon_star import MoonStar
from .icons.clock_1 import Clock1
from .icons.cigarette_off import CigaretteOff
from .icons.binary import Binary
from .icons.chevron_last import ChevronLast
from .icons.pointer_off import PointerOff
from .icons.mouse_pointer_2 import MousePointer2
from .icons.package_search import PackageSearch
from .icons.mic_off import MicOff
from .icons.lamp_desk import LampDesk
from .icons.text_align_start import TextAlignStart
from .icons.share import Share
from .icons.circle_parking_off import CircleParkingOff
from .icons.tags import Tags
from .icons.square_bottom_dashed_scissors import SquareBottomDashedScissors
from .icons.album import Album
from .icons.key_round import KeyRound
from .icons.square_code import SquareCode
from .icons.folder_search_2 import FolderSearch2
from .icons.arrow_up import ArrowUp
from .icons.circle_arrow_out_up_left import CircleArrowOutUpLeft
from .icons.wifi_high import WifiHigh
from .icons.microscope import Microscope
from .icons.test_tube import TestTube
from .icons.bell_off import BellOff
from .icons.linkedin import Linkedin
from .icons.arrow_down_narrow_wide import ArrowDownNarrowWide
from .icons.clock_3 import Clock3
from .icons.panel_right import PanelRight
from .icons.drum import Drum
from .icons.view import View
from .icons.music_2 import Music2
from .icons.git_compare_arrows import GitCompareArrows
from .icons.ev_charger import EvCharger
from .icons.calendar_minus import CalendarMinus
from .icons.book_image import BookImage
from .icons.user_round_x import UserRoundX
from .icons.undo import Undo
from .icons.video import Video
from .icons.circle_ellipsis import CircleEllipsis
from .icons.id_card import IdCard
from .icons.activity import Activity
from .icons.pencil_line import PencilLine
from .icons.square_stop import SquareStop
from .icons.person_standing import PersonStanding
from .icons.twitter import Twitter
from .icons.map_pin import MapPin
from .icons.folder_input import FolderInput
from .icons.brush_cleaning import BrushCleaning
from .icons.clock_arrow_up import ClockArrowUp
from .icons.chess_pawn import ChessPawn
from .icons.lightbulb_off import LightbulbOff
from .icons.phone_incoming import PhoneIncoming
from .icons.refrigerator import Refrigerator
from .icons.italic import Italic
from .icons.list_end import ListEnd
from .icons.handshake import Handshake
from .icons.map_pin_check import MapPinCheck
from .icons.chevrons_left import ChevronsLeft
from .icons.rows_2 import Rows2
from .icons.mail_x import MailX
from .icons.medal import Medal
from .icons.message_circle_code import MessageCircleCode
from .icons.calendar import Calendar
from .icons.inspection_panel import InspectionPanel
from .icons.notepad_text import NotepadText
from .icons.message_circle_x import MessageCircleX
from .icons.arrow_right_from_line import ArrowRightFromLine
from .icons.tool_case import ToolCase
from .icons.globe import Globe
from .icons.arrow_left import ArrowLeft
from .icons.paintbrush import Paintbrush
from .icons.rows_3 import Rows3
from .icons.badge_swiss_franc import BadgeSwissFranc
from .icons.text_wrap import TextWrap
from .icons.cross import Cross
from .icons.square_minus import SquareMinus
from .icons.university import University
from .icons.route import Route
from .icons.circle_arrow_up import CircleArrowUp
from .icons.diameter import Diameter
from .icons.pc_case import PcCase
from .icons.ellipsis import Ellipsis
from .icons.calendar_heart import CalendarHeart
from .icons.book_headphones import BookHeadphones
from .icons.microchip import Microchip
from .icons.bottle_wine import BottleWine
from .icons.arrow_down_right import ArrowDownRight
from .icons.file_box import FileBox
from .icons.paw_print import PawPrint
from .icons.laptop import Laptop
from .icons.power_off import PowerOff
from .icons.redo_dot import RedoDot
from .icons.axis_3d import Axis3d
from .icons.chart_area import ChartArea
from .icons.arrow_big_up import ArrowBigUp
from .icons.framer import Framer
from .icons.keyboard_off import KeyboardOff
from .icons.map_plus import MapPlus
from .icons.mountain import Mountain
from .icons.stretch_horizontal import StretchHorizontal
from .icons.bell_dot import BellDot
from .icons.clipboard_x import ClipboardX
from .icons.folder_down import FolderDown
from .icons.panel_bottom_dashed import PanelBottomDashed
from .icons.chess_queen import ChessQueen
from .icons.volume_x import VolumeX
from .icons.music_3 import Music3
from .icons.copy_slash import CopySlash
from .icons.file_code import FileCode
from .icons.save_off import SaveOff
from .icons.move_left import MoveLeft
from .icons.slack import Slack
from .icons.circle_dashed import CircleDashed
from .icons.clock_2 import Clock2
from .icons.user_round_minus import UserRoundMinus
from .icons.scissors_line_dashed import ScissorsLineDashed
from .icons.file_output import FileOutput
from .icons.cloud import Cloud
from .icons.hop_off import HopOff
from .icons.clock_11 import Clock11
from .icons.shuffle import Shuffle
from .icons.quote import Quote
from .icons.anvil import Anvil
from .icons.washing_machine import WashingMachine
from .icons.grip_vertical import GripVertical
from .icons.clock_6 import Clock6
from .icons.drill import Drill
from .icons.file_braces import FileBraces
from .icons.align_horizontal_distribute_start import AlignHorizontalDistributeStart
from .icons.list_check import ListCheck
from .icons.file_type import FileType
from .icons.rewind import Rewind
from .icons.wine_off import WineOff
from .icons.circle_fading_arrow_up import CircleFadingArrowUp
from .icons.upload import Upload
from .icons.trending_down import TrendingDown
from .icons.bookmark_check import BookmarkCheck
from .icons.fold_vertical import FoldVertical
from .icons.calendar_x import CalendarX
from .icons.closed_caption import ClosedCaption
from .icons.pause import Pause
from .icons.radical import Radical
from .icons.arrow_big_up_dash import ArrowBigUpDash
from .icons.squircle_dashed import SquircleDashed
from .icons.folder_key import FolderKey
from .icons.grid_2x2 import Grid2x2
from .icons.cloud_hail import CloudHail
from .icons.search_x import SearchX
from .icons.chromium import Chromium
from .icons.cloudy import Cloudy
from .icons.replace import Replace
from .icons.forward import Forward
from .icons.mountain_snow import MountainSnow
from .icons.circle_minus import CircleMinus
from .icons.dices import Dices
from .icons.blend import Blend
from .icons.bookmark import Bookmark
from .icons.funnel_plus import FunnelPlus
from .icons.file_exclamation_point import FileExclamationPoint
from .icons.braces import Braces
from .icons.rocket import Rocket
from .icons.circle_dot import CircleDot
from .icons.move_right import MoveRight
from .icons.drama import Drama
from .icons.asterisk import Asterisk
from .icons.user_check import UserCheck
from .icons.calendar_clock import CalendarClock
from .icons.fish_off import FishOff
from .icons.folder_search import FolderSearch
from .icons.folder_pen import FolderPen
from .icons.cloud_sun_rain import CloudSunRain
from .icons.file_chart_pie import FileChartPie
from .icons.git_pull_request_create import GitPullRequestCreate
from .icons.tablet import Tablet
from .icons.mail_check import MailCheck
from .icons.align_vertical_justify_center import AlignVerticalJustifyCenter
from .icons.file_diff import FileDiff
from .icons.monitor_dot import MonitorDot
from .icons.ticket_slash import TicketSlash
from .icons.align_horizontal_space_between import AlignHorizontalSpaceBetween
from .icons.webhook import Webhook
from .icons.briefcase_conveyor_belt import BriefcaseConveyorBelt
from .icons.diamond_percent import DiamondPercent
from .icons.folder_open_dot import FolderOpenDot
from .icons.arrow_left_right import ArrowLeftRight
from .icons.code_xml import CodeXml
from .icons.cloud_download import CloudDownload
from .icons.utility_pole import UtilityPole
from .icons.square_dashed import SquareDashed
from .icons.signal_zero import SignalZero
from .icons.squares_unite import SquaresUnite
from .icons.book_up_2 import BookUp2
from .icons.monitor_off import MonitorOff
from .icons.ear import Ear
from .icons.spell_check import SpellCheck
from .icons.file_terminal import FileTerminal
from .icons.flame import Flame
from .icons.gallery_horizontal_end import GalleryHorizontalEnd
from .icons.nut_off import NutOff
from .icons.component import Component
from .icons.wifi_cog import WifiCog
from .icons.circle_off import CircleOff
from .icons.align_start_horizontal import AlignStartHorizontal
from .icons.locate_fixed import LocateFixed
from .icons.lock_open import LockOpen
from .icons.loader_pinwheel import LoaderPinwheel
from .icons.atom import Atom
from .icons.cat import Cat
from .icons.file_check_corner import FileCheckCorner
from .icons.cloud_cog import CloudCog
from .icons.sword import Sword
from .icons.square_pilcrow import SquarePilcrow
from .icons.squirrel import Squirrel
from .icons.menu import Menu
from .icons.pin_off import PinOff
from .icons.venus_and_mars import VenusAndMars
from .icons.lamp_ceiling import LampCeiling
from .icons.folder_dot import FolderDot
from .icons.utensils_crossed import UtensilsCrossed
from .icons.georgian_lari import GeorgianLari
from .icons.ratio import Ratio
from .icons.square_arrow_down_left import SquareArrowDownLeft
from .icons.grid_2x2_x import Grid2x2X
from .icons.octagon_alert import OctagonAlert
from .icons.gallery_vertical import GalleryVertical
from .icons.image_minus import ImageMinus
from .icons.clock_7 import Clock7
from .icons.arrow_right_to_line import ArrowRightToLine
from .icons.a_arrow_down import AArrowDown
from .icons.merge import Merge
from .icons.map_pinned import MapPinned
from .icons.square_pi import SquarePi
from .icons.align_horizontal_space_around import AlignHorizontalSpaceAround
from .icons.sticky_note import StickyNote
from .icons.ticket_plus import TicketPlus
from .icons.shopping_cart import ShoppingCart
from .icons.copy_x import CopyX
from .icons.calculator import Calculator
from .icons.clock_10 import Clock10
from .icons.train_front_tunnel import TrainFrontTunnel
from .icons.clock_12 import Clock12
from .icons.apple import Apple
from .icons.circle_chevron_left import CircleChevronLeft
from .icons.mouse import Mouse
from .icons.flask_conical import FlaskConical
from .icons.picture_in_picture_2 import PictureInPicture2
from .icons.pentagon import Pentagon
from .icons.diamond_minus import DiamondMinus
from .icons.waves_ladder import WavesLadder
from .icons.shield_check import ShieldCheck
from .icons.arrow_down_0_1 import ArrowDown01
from .icons.message_circle_reply import MessageCircleReply
from .icons.circle_pause import CirclePause
from .icons.mails import Mails
from .icons.clock_5 import Clock5
from .icons.chess_bishop import ChessBishop
from .icons.rectangle_horizontal import RectangleHorizontal
from .icons.shopping_basket import ShoppingBasket
from .icons.list_filter import ListFilter
from .icons.receipt_text import ReceiptText
from .icons.music_4 import Music4
from .icons.book_user import BookUser
from .icons.shield_ban import ShieldBan
from .icons.arrow_down_to_dot import ArrowDownToDot
from .icons.building import Building
from .icons.clipboard_copy import ClipboardCopy
from .icons.binoculars import Binoculars
from .icons.angry import Angry
from .icons.lollipop import Lollipop
from .icons.between_vertical_end import BetweenVerticalEnd
from .icons.history import History
from .icons.gavel import Gavel
from .icons.folder import Folder
from .icons.drafting_compass import DraftingCompass
from .icons.align_horizontal_distribute_center import AlignHorizontalDistributeCenter
from .icons.file_lock import FileLock
from .icons.layers_2 import Layers2
from .icons.users import Users
from .icons.chart_column_stacked import ChartColumnStacked
from .icons.boom_box import BoomBox
from .icons.slice import Slice
from .icons.folder_git import FolderGit
from .icons.flag_off import FlagOff
from .icons.mic_vocal import MicVocal
from .icons.heart_minus import HeartMinus
from .icons.corner_down_left import CornerDownLeft
from .icons.file_axis_3d import FileAxis3d
from .icons.book_open_text import BookOpenText
from .icons.timer import Timer
from .icons.gamepad import Gamepad
from .icons.git_commit_horizontal import GitCommitHorizontal
from .icons.monitor import Monitor
from .icons.clipboard_check import ClipboardCheck
from .icons.unlink_2 import Unlink2
from .icons.square_arrow_out_down_right import SquareArrowOutDownRight
from .icons.minus import Minus
from .icons.heart_pulse import HeartPulse
from .icons.rows_4 import Rows4
from .icons.heart_handshake import HeartHandshake
from .icons.birdhouse import Birdhouse
from .icons.bed_double import BedDouble
from .icons.gamepad_directional import GamepadDirectional
from .icons.text_search import TextSearch
from .icons.audio_waveform import AudioWaveform
from .icons.navigation_2 import Navigation2
from .icons.paint_bucket import PaintBucket
from .icons.panel_left_right_dashed import PanelLeftRightDashed
from .icons.chevron_left import ChevronLeft
from .icons.move_up import MoveUp
from .icons.film import Film
from .icons.moon import Moon
from .icons.square_arrow_left import SquareArrowLeft
from .icons.panel_bottom_close import PanelBottomClose
from .icons.weight import Weight
from .icons.shield_off import ShieldOff
from .icons.scaling import Scaling
from .icons.cable import Cable
from .icons.accessibility import Accessibility
from .icons.move_up_right import MoveUpRight
from .icons.wallet_cards import WalletCards
from .icons.calendar_sync import CalendarSync
from .icons.bus_front import BusFront
from .icons.lamp_wall_down import LampWallDown
from .icons.mouse_pointer import MousePointer
from .icons.train_front import TrainFront
from .icons.calendar_minus_2 import CalendarMinus2
from .icons.ribbon import Ribbon
from .icons.square_stack import SquareStack
from .icons.flip_horizontal import FlipHorizontal
from .icons.map_pin_check_inside import MapPinCheckInside
from .icons.gallery_horizontal import GalleryHorizontal
from .icons.notebook import Notebook
from .icons.stamp import Stamp
from .icons.square_split_horizontal import SquareSplitHorizontal
from .icons.text_initial import TextInitial
from .icons.arrow_up_down import ArrowUpDown
from .icons.screen_share import ScreenShare
from .icons.calendar_days import CalendarDays
from .icons.separator_horizontal import SeparatorHorizontal
from .icons.ferris_wheel import FerrisWheel
from .icons.sofa import Sofa
from .icons.clock_4 import Clock4
from .icons.ticket_check import TicketCheck
from .icons.cherry import Cherry
from .icons.fingerprint_pattern import FingerprintPattern
from .icons.heart import Heart
from .icons.trending_up import TrendingUp




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlashlightOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flashlight-off'], 'items': [{'path': {'d': 'M16 16v4a2 2 0 0 1-2 2h-4a2 2 0 0 1-2-2V10c0-2-2-2-2-4'}}, {'path': {'d': 'M7 2h11v4c0 2-2 2-2 4v1'}}, {'line': {'x1': '11', 'x2': '18', 'y1': '6', 'y2': '6'}}, {'line': {'x1': '2', 'x2': '22', 'y1': '2', 'y2': '22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tally1(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tally-1'], 'items': [{'path': {'d': 'M4 4v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BellElectric(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bell-electric'], 'items': [{'path': {'d': 'M18.518 17.347A7 7 0 0 1 14 19'}}, {'path': {'d': 'M18.8 4A11 11 0 0 1 20 9'}}, {'path': {'d': 'M9 9h.01'}}, {'circle': {'cx': '20', 'cy': '16', 'r': '2'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '7'}}, {'rect': {'x': '4', 'y': '16', 'width': '10', 'height': '6', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ScrollText(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-scroll-text'], 'items': [{'path': {'d': 'M15 12h-5'}}, {'path': {'d': 'M15 8h-5'}}, {'path': {'d': 'M19 17V5a2 2 0 0 0-2-2H4'}}, {'path': {'d': 'M8 21h12a2 2 0 0 0 2-2v-1a1 1 0 0 0-1-1H11a1 1 0 0 0-1 1v1a2 2 0 1 1-4 0V5a2 2 0 1 0-4 0v2a1 1 0 0 0 1 1h3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PictureInPicture2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-picture-in-picture-2'], 'items': [{'path': {'d': 'M21 9V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v10c0 1.1.9 2 2 2h4'}}, {'rect': {'width': '10', 'height': '7', 'x': '12', 'y': '13', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Brush(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-brush'], 'items': [{'path': {'d': 'm11 10 3 3'}}, {'path': {'d': 'M6.5 21A3.5 3.5 0 1 0 3 17.5a2.62 2.62 0 0 1-.708 1.792A1 1 0 0 0 3 21z'}}, {'path': {'d': 'M9.969 17.031 21.378 5.624a1 1 0 0 0-3.002-3.002L6.967 14.031'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowLeftToLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-left-to-line'], 'items': [{'path': {'d': 'M3 19V5'}}, {'path': {'d': 'm13 6-6 6 6 6'}}, {'path': {'d': 'M7 12h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChessPawn(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chess-pawn'], 'items': [{'path': {'d': 'M5 20a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1z'}}, {'path': {'d': 'm14.5 10 1.5 8'}}, {'path': {'d': 'M7 10h10'}}, {'path': {'d': 'm8 18 1.5-8'}}, {'circle': {'cx': '12', 'cy': '6', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-up'], 'items': [{'path': {'d': 'M8 6L12 2L16 6'}}, {'path': {'d': 'M12 2V22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Drumstick(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-drumstick'], 'items': [{'path': {'d': 'M15.4 15.63a7.875 6 135 1 1 6.23-6.23 4.5 3.43 135 0 0-6.23 6.23'}}, {'path': {'d': 'm8.29 12.71-2.6 2.6a2.5 2.5 0 1 0-1.65 4.65A2.5 2.5 0 1 0 8.7 18.3l2.59-2.59'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Subscript(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-subscript'], 'items': [{'path': {'d': 'm4 5 8 8'}}, {'path': {'d': 'm12 5-8 8'}}, {'path': {'d': 'M20 19h-4c0-1.5.44-2 1.5-2.5S20 15.33 20 14c0-.47-.17-.93-.48-1.29a2.11 2.11 0 0 0-2.62-.44c-.42.24-.74.62-.9 1.07'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def NotebookText(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-notebook-text'], 'items': [{'path': {'d': 'M2 6h4'}}, {'path': {'d': 'M2 10h4'}}, {'path': {'d': 'M2 14h4'}}, {'path': {'d': 'M2 18h4'}}, {'rect': {'width': '16', 'height': '20', 'x': '4', 'y': '2', 'rx': '2'}}, {'path': {'d': 'M9.5 8h5'}}, {'path': {'d': 'M9.5 12H16'}}, {'path': {'d': 'M9.5 16H14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PhilippinePeso(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-philippine-peso'], 'items': [{'path': {'d': 'M20 11H4'}}, {'path': {'d': 'M20 7H4'}}, {'path': {'d': 'M7 21V4a1 1 0 0 1 1-1h4a1 1 0 0 1 0 12H7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DatabaseBackup(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-database-backup'], 'items': [{'ellipse': {'cx': '12', 'cy': '5', 'rx': '9', 'ry': '3'}}, {'path': {'d': 'M3 12a9 3 0 0 0 5 2.69'}}, {'path': {'d': 'M21 9.3V5'}}, {'path': {'d': 'M3 5v14a9 3 0 0 0 6.47 2.88'}}, {'path': {'d': 'M12 12v4h4'}}, {'path': {'d': 'M13 20a5 5 0 0 0 9-3 4.5 4.5 0 0 0-4.5-4.5c-1.33 0-2.54.54-3.41 1.41L12 16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Heading1(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heading-1'], 'items': [{'path': {'d': 'M4 12h8'}}, {'path': {'d': 'M4 18V6'}}, {'path': {'d': 'M12 18V6'}}, {'path': {'d': 'm17 12 3-2v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareMousePointer(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-mouse-pointer'], 'items': [{'path': {'d': 'M12.034 12.681a.498.498 0 0 1 .647-.647l9 3.5a.5.5 0 0 1-.033.943l-3.444 1.068a1 1 0 0 0-.66.66l-1.067 3.443a.5.5 0 0 1-.943.033z'}}, {'path': {'d': 'M21 11V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareArrowOutUpLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-arrow-out-up-left'], 'items': [{'path': {'d': 'M13 3h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-6'}}, {'path': {'d': 'm3 3 9 9'}}, {'path': {'d': 'M3 9V3h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Milestone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-milestone'], 'items': [{'path': {'d': 'M12 13v8'}}, {'path': {'d': 'M12 3v3'}}, {'path': {'d': 'M4 6a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h13a2 2 0 0 0 1.152-.365l3.424-2.317a1 1 0 0 0 0-1.635l-3.424-2.318A2 2 0 0 0 17 6z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Megaphone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-megaphone'], 'items': [{'path': {'d': 'M11 6a13 13 0 0 0 8.4-2.8A1 1 0 0 1 21 4v12a1 1 0 0 1-1.6.8A13 13 0 0 0 11 14H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2z'}}, {'path': {'d': 'M6 14a12 12 0 0 0 2.4 7.2 2 2 0 0 0 3.2-2.4A8 8 0 0 1 10 14'}}, {'path': {'d': 'M8 6v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChessRook(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chess-rook'], 'items': [{'path': {'d': 'M5 20a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1H6a1 1 0 0 1-1-1z'}}, {'path': {'d': 'M10 2v2'}}, {'path': {'d': 'M14 2v2'}}, {'path': {'d': 'm17 18-1-9'}}, {'path': {'d': 'M6 2v5a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V2'}}, {'path': {'d': 'M6 4h12'}}, {'path': {'d': 'm7 18 1-9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BellOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bell-off'], 'items': [{'path': {'d': 'M10.268 21a2 2 0 0 0 3.464 0'}}, {'path': {'d': 'M17 17H4a1 1 0 0 1-.74-1.673C4.59 13.956 6 12.499 6 8a6 6 0 0 1 .258-1.742'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M8.668 3.01A6 6 0 0 1 18 8c0 2.687.77 4.653 1.707 6.05'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Option(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-option'], 'items': [{'path': {'d': 'M3 3h6l6 18h6'}}, {'path': {'d': 'M14 3h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Database(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-database'], 'items': [{'ellipse': {'cx': '12', 'cy': '5', 'rx': '9', 'ry': '3'}}, {'path': {'d': 'M3 5V19A9 3 0 0 0 21 19V5'}}, {'path': {'d': 'M3 12A9 3 0 0 0 21 12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleUserRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-user-round'], 'items': [{'path': {'d': 'M18 20a6 6 0 0 0-12 0'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '4'}}, {'circle': {'cx': '12', 'cy': '12', 'r': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Shell(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shell'], 'items': [{'path': {'d': 'M14 11a2 2 0 1 1-4 0 4 4 0 0 1 8 0 6 6 0 0 1-12 0 8 8 0 0 1 16 0 10 10 0 1 1-20 0 11.93 11.93 0 0 1 2.42-7.22 2 2 0 1 1 3.16 2.44'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Combine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-combine'], 'items': [{'path': {'d': 'M14 3a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1'}}, {'path': {'d': 'M19 3a1 1 0 0 1 1 1v5a1 1 0 0 1-1 1'}}, {'path': {'d': 'm7 15 3 3'}}, {'path': {'d': 'm7 21 3-3H5a2 2 0 0 1-2-2v-2'}}, {'rect': {'x': '14', 'y': '14', 'width': '7', 'height': '7', 'rx': '1'}}, {'rect': {'x': '3', 'y': '3', 'width': '7', 'height': '7', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Kanban(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-kanban'], 'items': [{'path': {'d': 'M5 3v14'}}, {'path': {'d': 'M12 3v8'}}, {'path': {'d': 'M19 3v18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TestTubes(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-test-tubes'], 'items': [{'path': {'d': 'M9 2v17.5A2.5 2.5 0 0 1 6.5 22A2.5 2.5 0 0 1 4 19.5V2'}}, {'path': {'d': 'M20 2v17.5a2.5 2.5 0 0 1-2.5 2.5a2.5 2.5 0 0 1-2.5-2.5V2'}}, {'path': {'d': 'M3 2h7'}}, {'path': {'d': 'M14 2h7'}}, {'path': {'d': 'M9 16H4'}}, {'path': {'d': 'M20 16h-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HeadphoneOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-headphone-off'], 'items': [{'path': {'d': 'M21 14h-1.343'}}, {'path': {'d': 'M9.128 3.47A9 9 0 0 1 21 12v3.343'}}, {'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M20.414 20.414A2 2 0 0 1 19 21h-1a2 2 0 0 1-2-2v-3'}}, {'path': {'d': 'M3 14h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-7a9 9 0 0 1 2.636-6.364'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClipboardCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clipboard-check'], 'items': [{'rect': {'width': '8', 'height': '4', 'x': '8', 'y': '2', 'rx': '1', 'ry': '1'}}, {'path': {'d': 'M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2'}}, {'path': {'d': 'm9 14 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MailQuestionMark(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-mail-question-mark'], 'items': [{'path': {'d': 'M22 10.5V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h12.5'}}, {'path': {'d': 'm22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7'}}, {'path': {'d': 'M18 15.28c.2-.4.5-.8.9-1a2.1 2.1 0 0 1 2.6.4c.3.4.5.8.5 1.3 0 1.3-2 2-2 2'}}, {'path': {'d': 'M20 22v.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownToLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-to-line'], 'items': [{'path': {'d': 'M12 17V3'}}, {'path': {'d': 'm6 11 6 6 6-6'}}, {'path': {'d': 'M19 21H5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareRoundCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-round-corner'], 'items': [{'path': {'d': 'M21 11a8 8 0 0 0-8-8'}}, {'path': {'d': 'M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Presentation(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-presentation'], 'items': [{'path': {'d': 'M2 3h20'}}, {'path': {'d': 'M21 3v11a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V3'}}, {'path': {'d': 'm7 21 5-5 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Network(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-network'], 'items': [{'rect': {'x': '16', 'y': '16', 'width': '6', 'height': '6', 'rx': '1'}}, {'rect': {'x': '2', 'y': '16', 'width': '6', 'height': '6', 'rx': '1'}}, {'rect': {'x': '9', 'y': '2', 'width': '6', 'height': '6', 'rx': '1'}}, {'path': {'d': 'M5 16v-3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v3'}}, {'path': {'d': 'M12 12V8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Plug2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-plug-2'], 'items': [{'path': {'d': 'M9 2v6'}}, {'path': {'d': 'M15 2v6'}}, {'path': {'d': 'M12 17v5'}}, {'path': {'d': 'M5 8h14'}}, {'path': {'d': 'M6 11V8h12v3a6 6 0 1 1-12 0Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PillBottle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pill-bottle'], 'items': [{'path': {'d': 'M18 11h-4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h4'}}, {'path': {'d': 'M6 7v13a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V7'}}, {'rect': {'width': '16', 'height': '5', 'x': '4', 'y': '2', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Popcorn(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-popcorn'], 'items': [{'path': {'d': 'M18 8a2 2 0 0 0 0-4 2 2 0 0 0-4 0 2 2 0 0 0-4 0 2 2 0 0 0-4 0 2 2 0 0 0 0 4'}}, {'path': {'d': 'M10 22 9 8'}}, {'path': {'d': 'm14 22 1-14'}}, {'path': {'d': 'M20 8c.5 0 .9.4.8 1l-2.6 12c-.1.5-.7 1-1.2 1H7c-.6 0-1.1-.4-1.2-1L3.2 9c-.1-.6.3-1 .8-1Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageCircleMore(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-circle-more'], 'items': [{'path': {'d': 'M2.992 16.342a2 2 0 0 1 .094 1.167l-1.065 3.29a1 1 0 0 0 1.236 1.168l3.413-.998a2 2 0 0 1 1.099.092 10 10 0 1 0-4.777-4.719'}}, {'path': {'d': 'M8 12h.01'}}, {'path': {'d': 'M12 12h.01'}}, {'path': {'d': 'M16 12h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Heading4(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heading-4'], 'items': [{'path': {'d': 'M12 18V6'}}, {'path': {'d': 'M17 10v3a1 1 0 0 0 1 1h3'}}, {'path': {'d': 'M21 10v8'}}, {'path': {'d': 'M4 12h8'}}, {'path': {'d': 'M4 18V6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BadgePoundSterling(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-badge-pound-sterling'], 'items': [{'path': {'d': 'M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z'}}, {'path': {'d': 'M8 12h4'}}, {'path': {'d': 'M10 16V9.5a2.5 2.5 0 0 1 5 0'}}, {'path': {'d': 'M8 16h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerUpLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-up-left'], 'items': [{'path': {'d': 'M20 20v-7a4 4 0 0 0-4-4H4'}}, {'path': {'d': 'M9 14 4 9l5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Pipette(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pipette'], 'items': [{'path': {'d': 'm12 9-8.414 8.414A2 2 0 0 0 3 18.828v1.344a2 2 0 0 1-.586 1.414A2 2 0 0 1 3.828 21h1.344a2 2 0 0 0 1.414-.586L15 12'}}, {'path': {'d': 'm18 9 .4.4a1 1 0 1 1-3 3l-3.8-3.8a1 1 0 1 1 3-3l.4.4 3.4-3.4a1 1 0 1 1 3 3z'}}, {'path': {'d': 'm2 22 .414-.414'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Upload(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-upload'], 'items': [{'path': {'d': 'M12 3v12'}}, {'path': {'d': 'm17 8-5-5-5 5'}}, {'path': {'d': 'M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownFromLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-from-line'], 'items': [{'path': {'d': 'M19 3H5'}}, {'path': {'d': 'M12 21V7'}}, {'path': {'d': 'm6 15 6 6 6-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Syringe(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-syringe'], 'items': [{'path': {'d': 'm18 2 4 4'}}, {'path': {'d': 'm17 7 3-3'}}, {'path': {'d': 'M19 9 8.7 19.3c-1 1-2.5 1-3.4 0l-.6-.6c-1-1-1-2.5 0-3.4L15 5'}}, {'path': {'d': 'm9 11 4 4'}}, {'path': {'d': 'm5 19-3 3'}}, {'path': {'d': 'm14 4 6 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
